@@ -231,12 +231,14 @@ pub type bucket_key = u32;
 pub type feature_index = u32;
 #[inline]
 pub fn flann_distance_type() -> Result<crate::flann::flann_distance_t> {
-	unsafe { sys::cvflann_flann_distance_type() }.into_result()
+	let ret = unsafe { sys::cvflann_flann_distance_type() }.into_result()?;
+	Ok(ret)
 }
 
 #[inline]
 pub fn set_distance_type(distance_type: crate::flann::flann_distance_t, order: i32) -> Result<()> {
-	unsafe { sys::cvflann_set_distance_type_flann_distance_t_int(distance_type, order) }.into_result()
+	let ret = unsafe { sys::cvflann_set_distance_type_flann_distance_t_int(distance_type, order) }.into_result()?;
+	Ok(ret)
 }
 
 pub trait AutotunedIndexParamsTraitConst: crate::flann::IndexParamsTraitConst {
@@ -288,7 +290,9 @@ impl AutotunedIndexParams {
 	/// * sample_fraction: 0.1f
 	#[inline]
 	pub fn new(target_precision: f32, build_weight: f32, memory_weight: f32, sample_fraction: f32) -> Result<crate::flann::AutotunedIndexParams> {
-		unsafe { sys::cv_flann_AutotunedIndexParams_AutotunedIndexParams_float_float_float_float(target_precision, build_weight, memory_weight, sample_fraction) }.into_result().map(|r| unsafe { crate::flann::AutotunedIndexParams::opencv_from_extern(r) } )
+		let ret = unsafe { sys::cv_flann_AutotunedIndexParams_AutotunedIndexParams_float_float_float_float(target_precision, build_weight, memory_weight, sample_fraction) }.into_result()?;
+		let ret = unsafe { crate::flann::AutotunedIndexParams::opencv_from_extern(ret) };
+		Ok(ret)
 	}
 	
 }
@@ -345,7 +349,9 @@ impl CompositeIndexParams {
 	/// * cb_index: 0.2f
 	#[inline]
 	pub fn new(trees: i32, branching: i32, iterations: i32, centers_init: crate::flann::flann_centers_init_t, cb_index: f32) -> Result<crate::flann::CompositeIndexParams> {
-		unsafe { sys::cv_flann_CompositeIndexParams_CompositeIndexParams_int_int_int_flann_centers_init_t_float(trees, branching, iterations, centers_init, cb_index) }.into_result().map(|r| unsafe { crate::flann::CompositeIndexParams::opencv_from_extern(r) } )
+		let ret = unsafe { sys::cv_flann_CompositeIndexParams_CompositeIndexParams_int_int_int_flann_centers_init_t_float(trees, branching, iterations, centers_init, cb_index) }.into_result()?;
+		let ret = unsafe { crate::flann::CompositeIndexParams::opencv_from_extern(ret) };
+		Ok(ret)
 	}
 	
 }
@@ -401,7 +407,9 @@ impl HierarchicalClusteringIndexParams {
 	/// * leaf_size: 100
 	#[inline]
 	pub fn new(branching: i32, centers_init: crate::flann::flann_centers_init_t, trees: i32, leaf_size: i32) -> Result<crate::flann::HierarchicalClusteringIndexParams> {
-		unsafe { sys::cv_flann_HierarchicalClusteringIndexParams_HierarchicalClusteringIndexParams_int_flann_centers_init_t_int_int(branching, centers_init, trees, leaf_size) }.into_result().map(|r| unsafe { crate::flann::HierarchicalClusteringIndexParams::opencv_from_extern(r) } )
+		let ret = unsafe { sys::cv_flann_HierarchicalClusteringIndexParams_HierarchicalClusteringIndexParams_int_flann_centers_init_t_int_int(branching, centers_init, trees, leaf_size) }.into_result()?;
+		let ret = unsafe { crate::flann::HierarchicalClusteringIndexParams::opencv_from_extern(ret) };
+		Ok(ret)
 	}
 	
 }
@@ -414,17 +422,20 @@ pub trait IndexTraitConst {
 	#[inline]
 	fn save(&self, filename: &str) -> Result<()> {
 		extern_container_arg!(filename);
-		unsafe { sys::cv_flann_Index_save_const_const_StringR(self.as_raw_Index(), filename.opencv_as_extern()) }.into_result()
+		let ret = unsafe { sys::cv_flann_Index_save_const_const_StringR(self.as_raw_Index(), filename.opencv_as_extern()) }.into_result()?;
+		Ok(ret)
 	}
 	
 	#[inline]
 	fn get_distance(&self) -> Result<crate::flann::flann_distance_t> {
-		unsafe { sys::cv_flann_Index_getDistance_const(self.as_raw_Index()) }.into_result()
+		let ret = unsafe { sys::cv_flann_Index_getDistance_const(self.as_raw_Index()) }.into_result()?;
+		Ok(ret)
 	}
 	
 	#[inline]
 	fn get_algorithm(&self) -> Result<crate::flann::flann_algorithm_t> {
-		unsafe { sys::cv_flann_Index_getAlgorithm_const(self.as_raw_Index()) }.into_result()
+		let ret = unsafe { sys::cv_flann_Index_getAlgorithm_const(self.as_raw_Index()) }.into_result()?;
+		Ok(ret)
 	}
 	
 }
@@ -437,7 +448,8 @@ pub trait IndexTrait: crate::flann::IndexTraitConst {
 	#[inline]
 	fn build(&mut self, features: &dyn core::ToInputArray, params: &crate::flann::IndexParams, dist_type: crate::flann::flann_distance_t) -> Result<()> {
 		input_array_arg!(features);
-		unsafe { sys::cv_flann_Index_build_const__InputArrayR_const_IndexParamsR_flann_distance_t(self.as_raw_mut_Index(), features.as_raw__InputArray(), params.as_raw_IndexParams(), dist_type) }.into_result()
+		let ret = unsafe { sys::cv_flann_Index_build_const__InputArrayR_const_IndexParamsR_flann_distance_t(self.as_raw_mut_Index(), features.as_raw__InputArray(), params.as_raw_IndexParams(), dist_type) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// ## C++ default parameters
@@ -447,7 +459,8 @@ pub trait IndexTrait: crate::flann::IndexTraitConst {
 		input_array_arg!(query);
 		output_array_arg!(indices);
 		output_array_arg!(dists);
-		unsafe { sys::cv_flann_Index_knnSearch_const__InputArrayR_const__OutputArrayR_const__OutputArrayR_int_const_SearchParamsR(self.as_raw_mut_Index(), query.as_raw__InputArray(), indices.as_raw__OutputArray(), dists.as_raw__OutputArray(), knn, params.as_raw_SearchParams()) }.into_result()
+		let ret = unsafe { sys::cv_flann_Index_knnSearch_const__InputArrayR_const__OutputArrayR_const__OutputArrayR_int_const_SearchParamsR(self.as_raw_mut_Index(), query.as_raw__InputArray(), indices.as_raw__OutputArray(), dists.as_raw__OutputArray(), knn, params.as_raw_SearchParams()) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// ## C++ default parameters
@@ -457,19 +470,22 @@ pub trait IndexTrait: crate::flann::IndexTraitConst {
 		input_array_arg!(query);
 		output_array_arg!(indices);
 		output_array_arg!(dists);
-		unsafe { sys::cv_flann_Index_radiusSearch_const__InputArrayR_const__OutputArrayR_const__OutputArrayR_double_int_const_SearchParamsR(self.as_raw_mut_Index(), query.as_raw__InputArray(), indices.as_raw__OutputArray(), dists.as_raw__OutputArray(), radius, max_results, params.as_raw_SearchParams()) }.into_result()
+		let ret = unsafe { sys::cv_flann_Index_radiusSearch_const__InputArrayR_const__OutputArrayR_const__OutputArrayR_double_int_const_SearchParamsR(self.as_raw_mut_Index(), query.as_raw__InputArray(), indices.as_raw__OutputArray(), dists.as_raw__OutputArray(), radius, max_results, params.as_raw_SearchParams()) }.into_result()?;
+		Ok(ret)
 	}
 	
 	#[inline]
 	fn load(&mut self, features: &dyn core::ToInputArray, filename: &str) -> Result<bool> {
 		input_array_arg!(features);
 		extern_container_arg!(filename);
-		unsafe { sys::cv_flann_Index_load_const__InputArrayR_const_StringR(self.as_raw_mut_Index(), features.as_raw__InputArray(), filename.opencv_as_extern()) }.into_result()
+		let ret = unsafe { sys::cv_flann_Index_load_const__InputArrayR_const_StringR(self.as_raw_mut_Index(), features.as_raw__InputArray(), filename.opencv_as_extern()) }.into_result()?;
+		Ok(ret)
 	}
 	
 	#[inline]
 	fn release(&mut self) -> Result<()> {
-		unsafe { sys::cv_flann_Index_release(self.as_raw_mut_Index()) }.into_result()
+		let ret = unsafe { sys::cv_flann_Index_release(self.as_raw_mut_Index()) }.into_result()?;
+		Ok(ret)
 	}
 	
 }
@@ -500,7 +516,9 @@ impl crate::flann::IndexTrait for Index {
 impl Index {
 	#[inline]
 	pub fn default() -> Result<crate::flann::Index> {
-		unsafe { sys::cv_flann_Index_Index() }.into_result().map(|r| unsafe { crate::flann::Index::opencv_from_extern(r) } )
+		let ret = unsafe { sys::cv_flann_Index_Index() }.into_result()?;
+		let ret = unsafe { crate::flann::Index::opencv_from_extern(ret) };
+		Ok(ret)
 	}
 	
 	/// ## C++ default parameters
@@ -508,7 +526,9 @@ impl Index {
 	#[inline]
 	pub fn new(features: &dyn core::ToInputArray, params: &crate::flann::IndexParams, dist_type: crate::flann::flann_distance_t) -> Result<crate::flann::Index> {
 		input_array_arg!(features);
-		unsafe { sys::cv_flann_Index_Index_const__InputArrayR_const_IndexParamsR_flann_distance_t(features.as_raw__InputArray(), params.as_raw_IndexParams(), dist_type) }.into_result().map(|r| unsafe { crate::flann::Index::opencv_from_extern(r) } )
+		let ret = unsafe { sys::cv_flann_Index_Index_const__InputArrayR_const_IndexParamsR_flann_distance_t(features.as_raw__InputArray(), params.as_raw_IndexParams(), dist_type) }.into_result()?;
+		let ret = unsafe { crate::flann::Index::opencv_from_extern(ret) };
+		Ok(ret)
 	}
 	
 }
@@ -522,7 +542,9 @@ pub trait IndexParamsTraitConst {
 	fn get_string(&self, key: &str, default_val: &str) -> Result<String> {
 		extern_container_arg!(key);
 		extern_container_arg!(default_val);
-		unsafe { sys::cv_flann_IndexParams_getString_const_const_StringR_const_StringR(self.as_raw_IndexParams(), key.opencv_as_extern(), default_val.opencv_as_extern()) }.into_result().map(|r| unsafe { String::opencv_from_extern(r) } )
+		let ret = unsafe { sys::cv_flann_IndexParams_getString_const_const_StringR_const_StringR(self.as_raw_IndexParams(), key.opencv_as_extern(), default_val.opencv_as_extern()) }.into_result()?;
+		let ret = unsafe { String::opencv_from_extern(ret) };
+		Ok(ret)
 	}
 	
 	/// ## C++ default parameters
@@ -530,7 +552,8 @@ pub trait IndexParamsTraitConst {
 	#[inline]
 	fn get_int(&self, key: &str, default_val: i32) -> Result<i32> {
 		extern_container_arg!(key);
-		unsafe { sys::cv_flann_IndexParams_getInt_const_const_StringR_int(self.as_raw_IndexParams(), key.opencv_as_extern(), default_val) }.into_result()
+		let ret = unsafe { sys::cv_flann_IndexParams_getInt_const_const_StringR_int(self.as_raw_IndexParams(), key.opencv_as_extern(), default_val) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// ## C++ default parameters
@@ -538,12 +561,14 @@ pub trait IndexParamsTraitConst {
 	#[inline]
 	fn get_double(&self, key: &str, default_val: f64) -> Result<f64> {
 		extern_container_arg!(key);
-		unsafe { sys::cv_flann_IndexParams_getDouble_const_const_StringR_double(self.as_raw_IndexParams(), key.opencv_as_extern(), default_val) }.into_result()
+		let ret = unsafe { sys::cv_flann_IndexParams_getDouble_const_const_StringR_double(self.as_raw_IndexParams(), key.opencv_as_extern(), default_val) }.into_result()?;
+		Ok(ret)
 	}
 	
 	#[inline]
 	fn get_all(&self, names: &mut core::Vector<String>, types: &mut core::Vector<crate::flann::FlannIndexType>, str_values: &mut core::Vector<String>, num_values: &mut core::Vector<f64>) -> Result<()> {
-		unsafe { sys::cv_flann_IndexParams_getAll_const_vector_String_R_vector_FlannIndexType_R_vector_String_R_vector_double_R(self.as_raw_IndexParams(), names.as_raw_mut_VectorOfString(), types.as_raw_mut_VectorOfFlannIndexType(), str_values.as_raw_mut_VectorOfString(), num_values.as_raw_mut_VectorOff64()) }.into_result()
+		let ret = unsafe { sys::cv_flann_IndexParams_getAll_const_vector_String_R_vector_FlannIndexType_R_vector_String_R_vector_double_R(self.as_raw_IndexParams(), names.as_raw_mut_VectorOfString(), types.as_raw_mut_VectorOfFlannIndexType(), str_values.as_raw_mut_VectorOfString(), num_values.as_raw_mut_VectorOff64()) }.into_result()?;
+		Ok(ret)
 	}
 	
 }
@@ -553,48 +578,56 @@ pub trait IndexParamsTrait: crate::flann::IndexParamsTraitConst {
 
 	#[inline]
 	fn params(&mut self) -> *mut c_void {
-		unsafe { sys::cv_flann_IndexParams_getPropParams(self.as_raw_mut_IndexParams()) }.into_result().expect("Infallible function failed: params")
+		let ret = unsafe { sys::cv_flann_IndexParams_getPropParams(self.as_raw_mut_IndexParams()) };
+		ret
 	}
 	
 	#[inline]
 	fn set_params(&mut self, val: *mut c_void) {
-		unsafe { sys::cv_flann_IndexParams_setPropParams_voidX(self.as_raw_mut_IndexParams(), val) }.into_result().expect("Infallible function failed: set_params")
+		let ret = unsafe { sys::cv_flann_IndexParams_setPropParams_voidX(self.as_raw_mut_IndexParams(), val) };
+		ret
 	}
 	
 	#[inline]
 	fn set_string(&mut self, key: &str, value: &str) -> Result<()> {
 		extern_container_arg!(key);
 		extern_container_arg!(value);
-		unsafe { sys::cv_flann_IndexParams_setString_const_StringR_const_StringR(self.as_raw_mut_IndexParams(), key.opencv_as_extern(), value.opencv_as_extern()) }.into_result()
+		let ret = unsafe { sys::cv_flann_IndexParams_setString_const_StringR_const_StringR(self.as_raw_mut_IndexParams(), key.opencv_as_extern(), value.opencv_as_extern()) }.into_result()?;
+		Ok(ret)
 	}
 	
 	#[inline]
 	fn set_int(&mut self, key: &str, value: i32) -> Result<()> {
 		extern_container_arg!(key);
-		unsafe { sys::cv_flann_IndexParams_setInt_const_StringR_int(self.as_raw_mut_IndexParams(), key.opencv_as_extern(), value) }.into_result()
+		let ret = unsafe { sys::cv_flann_IndexParams_setInt_const_StringR_int(self.as_raw_mut_IndexParams(), key.opencv_as_extern(), value) }.into_result()?;
+		Ok(ret)
 	}
 	
 	#[inline]
 	fn set_double(&mut self, key: &str, value: f64) -> Result<()> {
 		extern_container_arg!(key);
-		unsafe { sys::cv_flann_IndexParams_setDouble_const_StringR_double(self.as_raw_mut_IndexParams(), key.opencv_as_extern(), value) }.into_result()
+		let ret = unsafe { sys::cv_flann_IndexParams_setDouble_const_StringR_double(self.as_raw_mut_IndexParams(), key.opencv_as_extern(), value) }.into_result()?;
+		Ok(ret)
 	}
 	
 	#[inline]
 	fn set_float(&mut self, key: &str, value: f32) -> Result<()> {
 		extern_container_arg!(key);
-		unsafe { sys::cv_flann_IndexParams_setFloat_const_StringR_float(self.as_raw_mut_IndexParams(), key.opencv_as_extern(), value) }.into_result()
+		let ret = unsafe { sys::cv_flann_IndexParams_setFloat_const_StringR_float(self.as_raw_mut_IndexParams(), key.opencv_as_extern(), value) }.into_result()?;
+		Ok(ret)
 	}
 	
 	#[inline]
 	fn set_bool(&mut self, key: &str, value: bool) -> Result<()> {
 		extern_container_arg!(key);
-		unsafe { sys::cv_flann_IndexParams_setBool_const_StringR_bool(self.as_raw_mut_IndexParams(), key.opencv_as_extern(), value) }.into_result()
+		let ret = unsafe { sys::cv_flann_IndexParams_setBool_const_StringR_bool(self.as_raw_mut_IndexParams(), key.opencv_as_extern(), value) }.into_result()?;
+		Ok(ret)
 	}
 	
 	#[inline]
 	fn set_algorithm(&mut self, value: i32) -> Result<()> {
-		unsafe { sys::cv_flann_IndexParams_setAlgorithm_int(self.as_raw_mut_IndexParams(), value) }.into_result()
+		let ret = unsafe { sys::cv_flann_IndexParams_setAlgorithm_int(self.as_raw_mut_IndexParams(), value) }.into_result()?;
+		Ok(ret)
 	}
 	
 }
@@ -625,7 +658,9 @@ impl crate::flann::IndexParamsTrait for IndexParams {
 impl IndexParams {
 	#[inline]
 	pub fn default() -> Result<crate::flann::IndexParams> {
-		unsafe { sys::cv_flann_IndexParams_IndexParams() }.into_result().map(|r| unsafe { crate::flann::IndexParams::opencv_from_extern(r) } )
+		let ret = unsafe { sys::cv_flann_IndexParams_IndexParams() }.into_result()?;
+		let ret = unsafe { crate::flann::IndexParams::opencv_from_extern(ret) };
+		Ok(ret)
 	}
 	
 }
@@ -676,7 +711,9 @@ impl KDTreeIndexParams {
 	/// * trees: 4
 	#[inline]
 	pub fn new(trees: i32) -> Result<crate::flann::KDTreeIndexParams> {
-		unsafe { sys::cv_flann_KDTreeIndexParams_KDTreeIndexParams_int(trees) }.into_result().map(|r| unsafe { crate::flann::KDTreeIndexParams::opencv_from_extern(r) } )
+		let ret = unsafe { sys::cv_flann_KDTreeIndexParams_KDTreeIndexParams_int(trees) }.into_result()?;
+		let ret = unsafe { crate::flann::KDTreeIndexParams::opencv_from_extern(ret) };
+		Ok(ret)
 	}
 	
 }
@@ -732,7 +769,9 @@ impl KMeansIndexParams {
 	/// * cb_index: 0.2f
 	#[inline]
 	pub fn new(branching: i32, iterations: i32, centers_init: crate::flann::flann_centers_init_t, cb_index: f32) -> Result<crate::flann::KMeansIndexParams> {
-		unsafe { sys::cv_flann_KMeansIndexParams_KMeansIndexParams_int_int_flann_centers_init_t_float(branching, iterations, centers_init, cb_index) }.into_result().map(|r| unsafe { crate::flann::KMeansIndexParams::opencv_from_extern(r) } )
+		let ret = unsafe { sys::cv_flann_KMeansIndexParams_KMeansIndexParams_int_int_flann_centers_init_t_float(branching, iterations, centers_init, cb_index) }.into_result()?;
+		let ret = unsafe { crate::flann::KMeansIndexParams::opencv_from_extern(ret) };
+		Ok(ret)
 	}
 	
 }
@@ -783,7 +822,9 @@ impl crate::flann::LinearIndexParamsTrait for LinearIndexParams {
 impl LinearIndexParams {
 	#[inline]
 	pub fn default() -> Result<crate::flann::LinearIndexParams> {
-		unsafe { sys::cv_flann_LinearIndexParams_LinearIndexParams() }.into_result().map(|r| unsafe { crate::flann::LinearIndexParams::opencv_from_extern(r) } )
+		let ret = unsafe { sys::cv_flann_LinearIndexParams_LinearIndexParams() }.into_result()?;
+		let ret = unsafe { crate::flann::LinearIndexParams::opencv_from_extern(ret) };
+		Ok(ret)
 	}
 	
 }
@@ -834,7 +875,9 @@ impl crate::flann::LshIndexParamsTrait for LshIndexParams {
 impl LshIndexParams {
 	#[inline]
 	pub fn new(table_number: i32, key_size: i32, multi_probe_level: i32) -> Result<crate::flann::LshIndexParams> {
-		unsafe { sys::cv_flann_LshIndexParams_LshIndexParams_int_int_int(table_number, key_size, multi_probe_level) }.into_result().map(|r| unsafe { crate::flann::LshIndexParams::opencv_from_extern(r) } )
+		let ret = unsafe { sys::cv_flann_LshIndexParams_LshIndexParams_int_int_int(table_number, key_size, multi_probe_level) }.into_result()?;
+		let ret = unsafe { crate::flann::LshIndexParams::opencv_from_extern(ret) };
+		Ok(ret)
 	}
 	
 }
@@ -886,7 +929,9 @@ impl SavedIndexParams {
 	#[inline]
 	pub fn new(filename: &str) -> Result<crate::flann::SavedIndexParams> {
 		extern_container_arg!(filename);
-		unsafe { sys::cv_flann_SavedIndexParams_SavedIndexParams_const_StringR(filename.opencv_as_extern()) }.into_result().map(|r| unsafe { crate::flann::SavedIndexParams::opencv_from_extern(r) } )
+		let ret = unsafe { sys::cv_flann_SavedIndexParams_SavedIndexParams_const_StringR(filename.opencv_as_extern()) }.into_result()?;
+		let ret = unsafe { crate::flann::SavedIndexParams::opencv_from_extern(ret) };
+		Ok(ret)
 	}
 	
 }
@@ -937,7 +982,9 @@ impl crate::flann::SearchParamsTrait for SearchParams {
 impl SearchParams {
 	#[inline]
 	pub fn new(checks: i32, eps: f32, sorted: bool, explore_all_trees: bool) -> Result<crate::flann::SearchParams> {
-		unsafe { sys::cv_flann_SearchParams_SearchParams_int_float_bool_bool(checks, eps, sorted, explore_all_trees) }.into_result().map(|r| unsafe { crate::flann::SearchParams::opencv_from_extern(r) } )
+		let ret = unsafe { sys::cv_flann_SearchParams_SearchParams_int_float_bool_bool(checks, eps, sorted, explore_all_trees) }.into_result()?;
+		let ret = unsafe { crate::flann::SearchParams::opencv_from_extern(ret) };
+		Ok(ret)
 	}
 	
 	/// ## C++ default parameters
@@ -946,7 +993,9 @@ impl SearchParams {
 	/// * sorted: true
 	#[inline]
 	pub fn new_1(checks: i32, eps: f32, sorted: bool) -> Result<crate::flann::SearchParams> {
-		unsafe { sys::cv_flann_SearchParams_SearchParams_int_float_bool(checks, eps, sorted) }.into_result().map(|r| unsafe { crate::flann::SearchParams::opencv_from_extern(r) } )
+		let ret = unsafe { sys::cv_flann_SearchParams_SearchParams_int_float_bool(checks, eps, sorted) }.into_result()?;
+		let ret = unsafe { crate::flann::SearchParams::opencv_from_extern(ret) };
+		Ok(ret)
 	}
 	
 }
