@@ -47,7 +47,8 @@ pub const SINUS: i32 = 2;
 pub fn ft02_d_fl_process(matrix: &dyn core::ToInputArray, radius: i32, output: &mut dyn core::ToOutputArray) -> Result<()> {
 	input_array_arg!(matrix);
 	output_array_arg!(output);
-	unsafe { sys::cv_ft_FT02D_FL_process_const__InputArrayR_const_int_const__OutputArrayR(matrix.as_raw__InputArray(), radius, output.as_raw__OutputArray()) }.into_result()
+	let ret = unsafe { sys::cv_ft_FT02D_FL_process_const__InputArrayR_const_int_const__OutputArrayR(matrix.as_raw__InputArray(), radius, output.as_raw__OutputArray()) }.into_result()?;
+	Ok(ret)
 }
 
 /// Sligtly less accurate version of ![inline formula](https://latex.codecogs.com/png.latex?F%5E0)-transfrom computation optimized for higher speed. The methods counts with linear basic function.
@@ -61,7 +62,8 @@ pub fn ft02_d_fl_process(matrix: &dyn core::ToInputArray, radius: i32, output: &
 pub fn ft02_d_fl_process_float(matrix: &dyn core::ToInputArray, radius: i32, output: &mut dyn core::ToOutputArray) -> Result<()> {
 	input_array_arg!(matrix);
 	output_array_arg!(output);
-	unsafe { sys::cv_ft_FT02D_FL_process_float_const__InputArrayR_const_int_const__OutputArrayR(matrix.as_raw__InputArray(), radius, output.as_raw__OutputArray()) }.into_result()
+	let ret = unsafe { sys::cv_ft_FT02D_FL_process_float_const__InputArrayR_const_int_const__OutputArrayR(matrix.as_raw__InputArray(), radius, output.as_raw__OutputArray()) }.into_result()?;
+	Ok(ret)
 }
 
 /// Computes components of the array using direct ![inline formula](https://latex.codecogs.com/png.latex?F%5E0)-transform.
@@ -81,7 +83,8 @@ pub fn ft02_d_components(matrix: &dyn core::ToInputArray, kernel: &dyn core::ToI
 	input_array_arg!(kernel);
 	output_array_arg!(components);
 	input_array_arg!(mask);
-	unsafe { sys::cv_ft_FT02D_components_const__InputArrayR_const__InputArrayR_const__OutputArrayR_const__InputArrayR(matrix.as_raw__InputArray(), kernel.as_raw__InputArray(), components.as_raw__OutputArray(), mask.as_raw__InputArray()) }.into_result()
+	let ret = unsafe { sys::cv_ft_FT02D_components_const__InputArrayR_const__InputArrayR_const__OutputArrayR_const__InputArrayR(matrix.as_raw__InputArray(), kernel.as_raw__InputArray(), components.as_raw__OutputArray(), mask.as_raw__InputArray()) }.into_result()?;
+	Ok(ret)
 }
 
 /// Computes inverse ![inline formula](https://latex.codecogs.com/png.latex?F%5E0)-transfrom.
@@ -98,7 +101,8 @@ pub fn ft02_d_inverse_ft(components: &dyn core::ToInputArray, kernel: &dyn core:
 	input_array_arg!(components);
 	input_array_arg!(kernel);
 	output_array_arg!(output);
-	unsafe { sys::cv_ft_FT02D_inverseFT_const__InputArrayR_const__InputArrayR_const__OutputArrayR_int_int(components.as_raw__InputArray(), kernel.as_raw__InputArray(), output.as_raw__OutputArray(), width, height) }.into_result()
+	let ret = unsafe { sys::cv_ft_FT02D_inverseFT_const__InputArrayR_const__InputArrayR_const__OutputArrayR_int_int(components.as_raw__InputArray(), kernel.as_raw__InputArray(), output.as_raw__OutputArray(), width, height) }.into_result()?;
+	Ok(ret)
 }
 
 /// Computes ![inline formula](https://latex.codecogs.com/png.latex?F%5E0)-transfrom and inverse ![inline formula](https://latex.codecogs.com/png.latex?F%5E0)-transfrom at once and return state.
@@ -118,7 +122,8 @@ pub fn ft02_d_iteration(matrix: &dyn core::ToInputArray, kernel: &dyn core::ToIn
 	output_array_arg!(output);
 	input_array_arg!(mask);
 	output_array_arg!(mask_output);
-	unsafe { sys::cv_ft_FT02D_iteration_const__InputArrayR_const__InputArrayR_const__OutputArrayR_const__InputArrayR_const__OutputArrayR_bool(matrix.as_raw__InputArray(), kernel.as_raw__InputArray(), output.as_raw__OutputArray(), mask.as_raw__InputArray(), mask_output.as_raw__OutputArray(), first_stop) }.into_result()
+	let ret = unsafe { sys::cv_ft_FT02D_iteration_const__InputArrayR_const__InputArrayR_const__OutputArrayR_const__InputArrayR_const__OutputArrayR_bool(matrix.as_raw__InputArray(), kernel.as_raw__InputArray(), output.as_raw__OutputArray(), mask.as_raw__InputArray(), mask_output.as_raw__OutputArray(), first_stop) }.into_result()?;
+	Ok(ret)
 }
 
 /// Computes ![inline formula](https://latex.codecogs.com/png.latex?F%5E0)-transfrom and inverse ![inline formula](https://latex.codecogs.com/png.latex?F%5E0)-transfrom at once.
@@ -138,7 +143,8 @@ pub fn ft02_d_process(matrix: &dyn core::ToInputArray, kernel: &dyn core::ToInpu
 	input_array_arg!(kernel);
 	output_array_arg!(output);
 	input_array_arg!(mask);
-	unsafe { sys::cv_ft_FT02D_process_const__InputArrayR_const__InputArrayR_const__OutputArrayR_const__InputArrayR(matrix.as_raw__InputArray(), kernel.as_raw__InputArray(), output.as_raw__OutputArray(), mask.as_raw__InputArray()) }.into_result()
+	let ret = unsafe { sys::cv_ft_FT02D_process_const__InputArrayR_const__InputArrayR_const__OutputArrayR_const__InputArrayR(matrix.as_raw__InputArray(), kernel.as_raw__InputArray(), output.as_raw__OutputArray(), mask.as_raw__InputArray()) }.into_result()?;
+	Ok(ret)
 }
 
 /// Computes components of the array using direct ![inline formula](https://latex.codecogs.com/png.latex?F%5E1)-transform.
@@ -153,7 +159,8 @@ pub fn ft12_d_components(matrix: &dyn core::ToInputArray, kernel: &dyn core::ToI
 	input_array_arg!(matrix);
 	input_array_arg!(kernel);
 	output_array_arg!(components);
-	unsafe { sys::cv_ft_FT12D_components_const__InputArrayR_const__InputArrayR_const__OutputArrayR(matrix.as_raw__InputArray(), kernel.as_raw__InputArray(), components.as_raw__OutputArray()) }.into_result()
+	let ret = unsafe { sys::cv_ft_FT12D_components_const__InputArrayR_const__InputArrayR_const__OutputArrayR(matrix.as_raw__InputArray(), kernel.as_raw__InputArray(), components.as_raw__OutputArray()) }.into_result()?;
+	Ok(ret)
 }
 
 /// Creates horizontal matrix for ![inline formula](https://latex.codecogs.com/png.latex?F%5E1)-transform computation.
@@ -166,7 +173,8 @@ pub fn ft12_d_components(matrix: &dyn core::ToInputArray, kernel: &dyn core::ToI
 #[inline]
 pub fn ft12_d_create_polynom_matrix_horizontal(radius: i32, matrix: &mut dyn core::ToOutputArray, chn: i32) -> Result<()> {
 	output_array_arg!(matrix);
-	unsafe { sys::cv_ft_FT12D_createPolynomMatrixHorizontal_int_const__OutputArrayR_const_int(radius, matrix.as_raw__OutputArray(), chn) }.into_result()
+	let ret = unsafe { sys::cv_ft_FT12D_createPolynomMatrixHorizontal_int_const__OutputArrayR_const_int(radius, matrix.as_raw__OutputArray(), chn) }.into_result()?;
+	Ok(ret)
 }
 
 /// Creates vertical matrix for ![inline formula](https://latex.codecogs.com/png.latex?F%5E1)-transform computation.
@@ -179,7 +187,8 @@ pub fn ft12_d_create_polynom_matrix_horizontal(radius: i32, matrix: &mut dyn cor
 #[inline]
 pub fn ft12_d_create_polynom_matrix_vertical(radius: i32, matrix: &mut dyn core::ToOutputArray, chn: i32) -> Result<()> {
 	output_array_arg!(matrix);
-	unsafe { sys::cv_ft_FT12D_createPolynomMatrixVertical_int_const__OutputArrayR_const_int(radius, matrix.as_raw__OutputArray(), chn) }.into_result()
+	let ret = unsafe { sys::cv_ft_FT12D_createPolynomMatrixVertical_int_const__OutputArrayR_const_int(radius, matrix.as_raw__OutputArray(), chn) }.into_result()?;
+	Ok(ret)
 }
 
 /// Computes inverse ![inline formula](https://latex.codecogs.com/png.latex?F%5E1)-transfrom.
@@ -196,7 +205,8 @@ pub fn ft12_d_inverse_ft(components: &dyn core::ToInputArray, kernel: &dyn core:
 	input_array_arg!(components);
 	input_array_arg!(kernel);
 	output_array_arg!(output);
-	unsafe { sys::cv_ft_FT12D_inverseFT_const__InputArrayR_const__InputArrayR_const__OutputArrayR_int_int(components.as_raw__InputArray(), kernel.as_raw__InputArray(), output.as_raw__OutputArray(), width, height) }.into_result()
+	let ret = unsafe { sys::cv_ft_FT12D_inverseFT_const__InputArrayR_const__InputArrayR_const__OutputArrayR_int_int(components.as_raw__InputArray(), kernel.as_raw__InputArray(), output.as_raw__OutputArray(), width, height) }.into_result()?;
+	Ok(ret)
 }
 
 /// Computes elements of ![inline formula](https://latex.codecogs.com/png.latex?F%5E1)-transform components.
@@ -222,7 +232,8 @@ pub fn ft12_d_polynomial(matrix: &dyn core::ToInputArray, kernel: &dyn core::ToI
 	output_array_arg!(c01);
 	output_array_arg!(components);
 	input_array_arg!(mask);
-	unsafe { sys::cv_ft_FT12D_polynomial_const__InputArrayR_const__InputArrayR_const__OutputArrayR_const__OutputArrayR_const__OutputArrayR_const__OutputArrayR_const__InputArrayR(matrix.as_raw__InputArray(), kernel.as_raw__InputArray(), c00.as_raw__OutputArray(), c10.as_raw__OutputArray(), c01.as_raw__OutputArray(), components.as_raw__OutputArray(), mask.as_raw__InputArray()) }.into_result()
+	let ret = unsafe { sys::cv_ft_FT12D_polynomial_const__InputArrayR_const__InputArrayR_const__OutputArrayR_const__OutputArrayR_const__OutputArrayR_const__OutputArrayR_const__InputArrayR(matrix.as_raw__InputArray(), kernel.as_raw__InputArray(), c00.as_raw__OutputArray(), c10.as_raw__OutputArray(), c01.as_raw__OutputArray(), components.as_raw__OutputArray(), mask.as_raw__InputArray()) }.into_result()?;
+	Ok(ret)
 }
 
 /// Computes ![inline formula](https://latex.codecogs.com/png.latex?F%5E1)-transfrom and inverse ![inline formula](https://latex.codecogs.com/png.latex?F%5E1)-transfrom at once.
@@ -246,7 +257,8 @@ pub fn ft12_d_process(matrix: &dyn core::ToInputArray, kernel: &dyn core::ToInpu
 	input_array_arg!(kernel);
 	output_array_arg!(output);
 	input_array_arg!(mask);
-	unsafe { sys::cv_ft_FT12D_process_const__InputArrayR_const__InputArrayR_const__OutputArrayR_const__InputArrayR(matrix.as_raw__InputArray(), kernel.as_raw__InputArray(), output.as_raw__OutputArray(), mask.as_raw__InputArray()) }.into_result()
+	let ret = unsafe { sys::cv_ft_FT12D_process_const__InputArrayR_const__InputArrayR_const__OutputArrayR_const__InputArrayR(matrix.as_raw__InputArray(), kernel.as_raw__InputArray(), output.as_raw__OutputArray(), mask.as_raw__InputArray()) }.into_result()?;
+	Ok(ret)
 }
 
 /// Creates kernel from basic functions.
@@ -262,7 +274,8 @@ pub fn create_kernel1(a: &dyn core::ToInputArray, b: &dyn core::ToInputArray, ke
 	input_array_arg!(a);
 	input_array_arg!(b);
 	output_array_arg!(kernel);
-	unsafe { sys::cv_ft_createKernel_const__InputArrayR_const__InputArrayR_const__OutputArrayR_const_int(a.as_raw__InputArray(), b.as_raw__InputArray(), kernel.as_raw__OutputArray(), chn) }.into_result()
+	let ret = unsafe { sys::cv_ft_createKernel_const__InputArrayR_const__InputArrayR_const__OutputArrayR_const_int(a.as_raw__InputArray(), b.as_raw__InputArray(), kernel.as_raw__OutputArray(), chn) }.into_result()?;
+	Ok(ret)
 }
 
 /// Creates kernel from general functions.
@@ -277,7 +290,8 @@ pub fn create_kernel1(a: &dyn core::ToInputArray, b: &dyn core::ToInputArray, ke
 #[inline]
 pub fn create_kernel(function: i32, radius: i32, kernel: &mut dyn core::ToOutputArray, chn: i32) -> Result<()> {
 	output_array_arg!(kernel);
-	unsafe { sys::cv_ft_createKernel_int_int_const__OutputArrayR_const_int(function, radius, kernel.as_raw__OutputArray(), chn) }.into_result()
+	let ret = unsafe { sys::cv_ft_createKernel_int_int_const__OutputArrayR_const_int(function, radius, kernel.as_raw__OutputArray(), chn) }.into_result()?;
+	Ok(ret)
 }
 
 /// Image filtering
@@ -292,7 +306,8 @@ pub fn filter(image: &dyn core::ToInputArray, kernel: &dyn core::ToInputArray, o
 	input_array_arg!(image);
 	input_array_arg!(kernel);
 	output_array_arg!(output);
-	unsafe { sys::cv_ft_filter_const__InputArrayR_const__InputArrayR_const__OutputArrayR(image.as_raw__InputArray(), kernel.as_raw__InputArray(), output.as_raw__OutputArray()) }.into_result()
+	let ret = unsafe { sys::cv_ft_filter_const__InputArrayR_const__InputArrayR_const__OutputArrayR(image.as_raw__InputArray(), kernel.as_raw__InputArray(), output.as_raw__OutputArray()) }.into_result()?;
+	Ok(ret)
 }
 
 /// Image inpainting
@@ -318,5 +333,6 @@ pub fn inpaint(image: &dyn core::ToInputArray, mask: &dyn core::ToInputArray, ou
 	input_array_arg!(image);
 	input_array_arg!(mask);
 	output_array_arg!(output);
-	unsafe { sys::cv_ft_inpaint_const__InputArrayR_const__InputArrayR_const__OutputArrayR_int_int_int(image.as_raw__InputArray(), mask.as_raw__InputArray(), output.as_raw__OutputArray(), radius, function, algorithm) }.into_result()
+	let ret = unsafe { sys::cv_ft_inpaint_const__InputArrayR_const__InputArrayR_const__OutputArrayR_int_int_int(image.as_raw__InputArray(), mask.as_raw__InputArray(), output.as_raw__OutputArray(), radius, function, algorithm) }.into_result()?;
+	Ok(ret)
 }
